@@ -22,4 +22,10 @@ def service(service_type: str, service_name: str, *args, **kwargs):
         return service
     except (AttributeError, ImportError, KeyError) as e:
         logging.error(e)
-        return None
\ No newline at end of file
+        return None
+
+
+def validate_language(lang):
+    if lang in [l[0] for l in settings.LANGUAGES]:
+        return lang
+    return 'en'
\ No newline at end of file
