@@ -4,7 +4,8 @@ from datetime import date, datetime
 from drf_yasg.utils import swagger_serializer_method
 from rest_framework import serializers
 
-from .models import Amount, UnitConversionPayload, Dimension
+from .models import Amount, UnitConversionPayload, Dimension, CustomUnit
+from geocurrency.core.serializers import UserSerializer
 
 
 class UnitAmountSerializer(serializers.Serializer):
@@ -82,7 +83,7 @@ class DimensionWithUnitsSerializer(DimensionSerializer):
     units = UnitSerializer(many=True)
 
     @swagger_serializer_method(serializer_or_field=UnitSerializer)
-    def get_units(self, obj):
+    def get_units(self, obj: Dimension):
         try:
             return obj.units
         except KeyError as e:
@@ -102,7 +103,7 @@ class UnitConversionPayloadSerializer(serializers.Serializer):
     key = serializers.CharField(required=False)
     eob = serializers.BooleanField(default=False)
 
-    def is_valid(self, raise_exception=False):
+    def is_valid(self, raise_exception=False) -> bool:
         if not self.initial_data.get('data') and (not self.initial_data.get('batch_id')
                                                   or (self.initial_data.get('batch_id')
                                                       and not self.initial_data.get('eob'))):
@@ -112,23 +113,23 @@ class UnitConversionPayloadSerializer(serializers.Serializer):
         return super(UnitConversionPayloadSerializer, self).is_valid()
 
     @staticmethod
-    def validate_base_system(value):
+    def validate_base_system(value: str):
         from geocurrency.units.models import UnitSystem
         if not UnitSystem.is_valid(value):
             raise serializers.ValidationError('Invalid unit system')
         return value
 
     @staticmethod
-    def validate_base_unit(value):
+    def validate_base_unit(value: str) -> str:
         from geocurrency.units.models import Unit
         if not Unit.is_valid(value):
             raise serializers.ValidationError('Invalid unit')
         return value
 
-    def create(self, validated_data):
+    def create(self, validated_data: {}):
         return UnitConversionPayload(**validated_data)
 
-    def update(self, instance, validated_data):
+    def update(self, instance, validated_data: {}):
         self.data = validated_data.get('data', instance.data)
         self.base_system = validated_data.get('base_system', instance.base_system)
         self.base_unit = validated_data.get('base_system', instance.base_unit)
@@ -136,3 +137,12 @@ class UnitConversionPayloadSerializer(serializers.Serializer):
         self.key = validated_data.get('key', instance.key)
         self.eob = validated_data.get('eob', instance.eob)
         return instance
+
+
+class CustomUnitSerializer(serializers.ModelSerializer):
+    user = UserSerializer(read_only=True)
+    unit_system = serializers.CharField(read_only=True)
+
+    class Meta:
+        model = CustomUnit
+        fields = ['user', 'key', 'unit_system', 'code', 'name', 'relation', 'symbol', 'alias']
\ No newline at end of file
